;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "elisp-depmap" "20251029.1438"
  "Generate an elisp dependency map in graphviz."
  '((emacs "26.1")
    (dash  "0"))
  :url "https://github.com/mtekman/elisp-depmap.el"
  :commit "c87e9ecae624b09d113c25b7ad1317d97eb2f434"
  :revdesc "c87e9ecae624"
  :keywords '("outlines"))
